biobroker.metadata\_entity package
==================================

.. automodule:: biobroker.metadata_entity
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

biobroker.metadata\_entity.exceptions module
--------------------------------------------

.. automodule:: biobroker.metadata_entity.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

biobroker.metadata\_entity.metadata\_entity module
--------------------------------------------------

.. automodule:: biobroker.metadata_entity.metadata_entity
   :members:
   :undoc-members:
   :show-inheritance:
